<?php

namespace App\Controllers;

use App\Models\CityModel;

class CityManagement extends BaseController
{
    protected $cityModel;

    public function __construct()
    {
        $this->cityModel = new CityModel();
    }

    public function index()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return redirect()->to('/dashboard')->with('error', 'Access denied.');
        }

        $data['cities'] = $this->cityModel->findAll();
        return view('city_management/index', $data);
    }

    public function add()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->response->setJSON(['success' => false, 'message' => 'Access denied.']);
        }

        $name = $this->request->getPost('name');
        $country = $this->request->getPost('country');

        $this->cityModel->insert([
            'name' => $name,
            'country' => $country
        ]);

        return $this->response->setJSON(['success' => true, 'message' => 'City added successfully.']);
    }

    public function delete($id)
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->response->setJSON(['success' => false, 'message' => 'Access denied.']);
        }

        $this->cityModel->delete($id);
        return $this->response->setJSON(['success' => true, 'message' => 'City deleted successfully.']);
    }
}