<?php

namespace App\Controllers;

use App\Models\RoomModel;
use App\Models\HotelModel;
use App\Models\RoomTypeModel;
use CodeIgniter\API\ResponseTrait;

class RoomManagement extends BaseController
{
    use ResponseTrait;

    protected $roomModel;
    protected $hotelModel;
    protected $roomTypeModel;

    public function __construct()
    {
        $this->roomModel = new RoomModel();
        $this->hotelModel = new HotelModel();
        $this->roomTypeModel = new RoomTypeModel();
    }

    public function index()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return redirect()->to('/dashboard')->with('error', 'Access denied.');
        }

        $data['rooms'] = $this->roomModel->findAll();
        $data['hotels'] = array_column($this->hotelModel->findAll(), null, 'id');
        $data['roomTypes'] = array_column($this->roomTypeModel->findAll(), null, 'id');
        
        // Fetch all room-hotel associations
        $data['hotelRooms'] = $this->roomModel->select('rooms.id, rooms.hotel_id, rooms.room_type_id')
            ->join('hotels', 'hotels.id = rooms.hotel_id')
            ->join('room_types', 'room_types.id = rooms.room_type_id')
            ->findAll();

        return view('room_management/index', $data);
    }

    public function add()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->respond(['success' => false, 'message' => 'Access denied.'], 403);
        }

        $roomTypeId = $this->request->getPost('room_type_id');
        $hotelId = $this->request->getPost('hotel_id');

        if ($this->roomModel->insert([
            'room_type_id' => $roomTypeId,
            'hotel_id' => $hotelId
        ])) {
            return $this->respond(['success' => true, 'message' => 'Room added successfully.'], 200);
        } else {
            return $this->respond(['success' => false, 'message' => 'Failed to add room.'], 400);
        }
    }

    public function delete($id)
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->respond(['success' => false, 'message' => 'Access denied.'], 403);
        }

        if ($this->roomModel->delete($id)) {
            return $this->respond(['success' => true, 'message' => 'Room deleted successfully.'], 200);
        } else {
            return $this->respond(['success' => false, 'message' => 'Failed to delete room.'], 400);
        }
    }

    public function addRoomType()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->respond(['success' => false, 'message' => 'Access denied.'], 403);
        }

        $rules = [
            'name' => 'required|min_length[2]|max_length[255]|is_unique[room_types.name]'
        ];

        if (!$this->validate($rules)) {
            return $this->respond(['success' => false, 'message' => $this->validator->getErrors()], 400);
        }

        $roomTypeName = $this->request->getPost('name');

        try {
            if ($this->roomTypeModel->insert(['name' => $roomTypeName])) {
                return $this->respond(['success' => true, 'message' => 'Room type added successfully.'], 200);
            } else {
                return $this->respond(['success' => false, 'message' => 'Failed to add room type.'], 400);
            }
        } catch (\Exception $e) {
            log_message('error', 'Error adding room type: ' . $e->getMessage());
            return $this->respond(['success' => false, 'message' => 'An error occurred while adding the room type.'], 500);
        }
    }
}