<?php

namespace App\Controllers;

use App\Models\RtqModel;
use App\Models\RequestModel;
use App\Libraries\PdfGenerator;
use App\Models\NoteModel;
use App\Models\RtqLogModel;
use Config\Email;
//require_once APPPATH . 'ThirdParty/tcpdf/tcpdf.php';



class Rtq extends BaseController
{
    protected $rtqModel;
    protected $requestModel;
  	protected $noteModel;
	protected $rtqLogModel;
  	
    public function __construct()
    {
        $this->rtqModel = new RtqModel();
        $this->requestModel = new RequestModel();
      	$this->rtqLogModel = new RtqLogModel();
      	$this->noteModel = new NoteModel();
    }

    public function index()
    {
        $data['rtqs'] = $this->rtqModel->getAllRtqs();
        return view('rtq/index', $data);
    }

    public function view($id)
    {
        $data['rtq'] = $this->rtqModel->getRtqDetails($id);
        
        if (!$data['rtq']) {
            return redirect()->to('/rtq')->with('error', 'RTQ not found');
        }

        $data['request'] = [
            'id' => $data['rtq']['request_id'],
            'unique_id' => $data['rtq']['unique_id'],
            'status' => $data['rtq']['request_status'],
            'created_at' => $data['rtq']['request_created_at'],
            'passengers' => $data['rtq']['passengers'] ?? []
        ];

        $data['notes'] = $this->noteModel->where('rtq_id', $id)->findAll();
        $data['logs'] = $this->rtqLogModel->getLogsWithUserInfo($id);
        
        return view('rtq/view', $data);
    }
  
  	private function logActivity($rtqId, $userId, $activity)
    {
        $this->rtqLogModel->insert([
            'rtq_id' => $rtqId,
            'user_id' => $userId,
            'activity' => $activity
        ]);
    }
  	
  	public function updateHotelStatus()
    {
        $rtqId = $this->request->getPost('rtq_id');
        $hotelId = $this->request->getPost('hotel_id');
        $status = $this->request->getPost('status');

        log_message('info', "Attempting to update hotel status: RTQ ID {$rtqId}, Hotel ID {$hotelId}, Status {$status}");

        if (empty($rtqId) || empty($hotelId) || empty($status)) {
            log_message('warning', "Missing required parameters for hotel status update");
            return $this->response->setJSON(['success' => false, 'message' => 'Missing required parameters']);
        }

        try {
            $success = $this->rtqModel->updateHotelStatus($rtqId, $hotelId, $status);
            
            if ($success) {
                $this->logActivity($rtqId, session()->get('user_id'), "Updated hotel status: Hotel ID {$hotelId} to {$status}");
                return $this->response->setJSON(['success' => true, 'message' => 'Hotel status updated successfully']);
            } else {
                $errorMessage = "Failed to update hotel status. Please check if the RTQ and Hotel IDs are correct.";
                log_message('error', $errorMessage . " RTQ ID {$rtqId}, Hotel ID {$hotelId}, Status {$status}");
                return $this->response->setJSON(['success' => false, 'message' => $errorMessage]);
            }
        } catch (\Exception $e) {
            log_message('error', "Error updating hotel status: " . $e->getMessage());
            return $this->response->setJSON(['success' => false, 'message' => 'An error occurred while updating hotel status']);
        }
    }
   	
  	public function generateVoucher($rtqId)
    {
        $rtq = $this->rtqModel->find($rtqId);
        if (!$rtq) {
            return $this->response->setJSON(['success' => false, 'message' => 'RTQ not found']);
        }

        $request = $this->requestModel->getRequestDetails($rtq['request_id']);
        $hotels = $this->rtqModel->getHotelsForRtq($rtq['request_id']);

        $pdfGenerator = new PdfGenerator();
        $pdfContent = $pdfGenerator->generateVoucher($rtq, $request, $hotels);

        // Save the voucher
        $voucherPath = FCPATH . 'uploads/vouchers/';
        if (!is_dir($voucherPath)) {
            mkdir($voucherPath, 0777, true);
        }
        $fileName = 'voucher_' . $rtq['id'] . '.pdf';
        file_put_contents($voucherPath . $fileName, $pdfContent);

        // Update RTQ with voucher path
        $this->rtqModel->update($rtqId, ['voucher_path' => 'uploads/vouchers/' . $fileName]);

        // Output PDF
        return $this->response
            ->setContentType('application/pdf')
            ->setHeader('Content-Disposition', 'attachment; filename="' . $fileName . '"')
            ->setBody($pdfContent);
    }
  	
  	public function addNote()
    {
        $rtqId = $this->request->getPost('rtq_id');
        $note = $this->request->getPost('note');
        $userId = session()->get('user_id'); // Assuming you have user sessions

        $this->noteModel->insert([
            'rtq_id' => $rtqId,
            'user_id' => $userId,
            'note' => $note
        ]);

        $this->logActivity($rtqId, $userId, 'Added a note');

        return redirect()->to("/rtq/view/$rtqId")->with('message', 'Note added successfully');
    }
  
  	public function downloadVoucher($rtqId)
	{
    $rtq = $this->rtqModel->find($rtqId);
    if (!$rtq || empty($rtq['voucher_path'])) {
        return $this->response->setJSON(['success' => false, 'message' => 'Voucher not found']);
    }

    $voucherPath = FCPATH . $rtq['voucher_path'];
    if (!file_exists($voucherPath)) {
        return $this->response->setJSON(['success' => false, 'message' => 'Voucher file not found']);
    }

    return $this->response->download($voucherPath, null);
	}
  
  
  
  
  
  	public function sendToHotel()
{
    $rtqId = $this->request->getPost('rtq_id');
    $hotelId = $this->request->getPost('hotel_id');
    
    log_message('info', "Attempting to send voucher to hotel: RTQ ID {$rtqId}, Hotel ID {$hotelId}");

    $rtq = $this->rtqModel->getRtqDetails($rtqId);
    if (!$rtq) {
        log_message('error', "RTQ not found for ID: {$rtqId}");
        return $this->response->setJSON(['success' => false, 'message' => 'RTQ not found']);
    }

    $hotel = null;
    foreach ($rtq['hotels'] as $h) {
        if ($h['hotel_id'] == $hotelId) {
            $hotel = $h;
            break;
        }
    }

    if (!$hotel) {
        log_message('error', "Hotel not found for RTQ ID: {$rtqId}, Hotel ID: {$hotelId}");
        return $this->response->setJSON(['success' => false, 'message' => 'Hotel not found']);
    }

    if (empty($hotel['hotel_email'])) {
        log_message('error', "Hotel email not found for Hotel ID: {$hotelId}");
        return $this->response->setJSON(['success' => false, 'message' => 'Hotel email not found']);
    }

    $requestModel = new \App\Models\RequestModel();
    $request = $requestModel->getRequestDetails($rtq['request_id']);

    if (!$request) {
        return $this->response->setJSON(['success' => false, 'message' => 'Request details not found']);
    }

    // Generate PDF for this specific hotel
    $pdfGenerator = new \App\Libraries\PdfGenerator();
    $pdfContent = $pdfGenerator->generateHotelVoucher($rtq, $request, $hotel);

    if (empty($pdfContent)) {
        log_message('error', 'Generated PDF content is empty');
        return $this->response->setJSON(['success' => false, 'message' => 'Failed to generate voucher: Empty content']);
    }

    // Create a unique filename for the PDF
    $voucherCount = $this->rtqModel->getVoucherCount($rtqId, $hotelId);
    $filename = "RTQ{$rtqId}-hotel{$hotelId}-v" . ($voucherCount + 1) . ".pdf";

    // Save the voucher
    $voucherPath = FCPATH . 'uploads/vouchers/';
    if (!is_dir($voucherPath)) {
        mkdir($voucherPath, 0777, true);
    }
    $fullPath = $voucherPath . $filename;
    if (file_put_contents($fullPath, $pdfContent) === false) {
        log_message('error', 'Failed to save voucher file: ' . $fullPath);
        return $this->response->setJSON(['success' => false, 'message' => 'Failed to save voucher']);
    }

    log_message('info', 'Voucher saved: ' . $fullPath);

    // Send email with PDF
    $email = \Config\Services::email();
    $emailConfig = new \Config\Email();

    $email->initialize($emailConfig);
    $email->setFrom($emailConfig->fromEmail, $emailConfig->fromName);
    $email->setTo($hotel['hotel_email']);
    $email->setSubject('Hotel Booking Voucher');
    $email->setMessage('Please find attached the voucher for the booking.');
    $email->attach($fullPath, 'application/pdf', $filename);

    $emailSent = false;
    if ($email->send(false)) {
        log_message('info', "Email sent successfully to hotel: {$hotel['hotel_name']}");
        
        // Update hotel status
        $statusUpdateSuccess = $this->rtqModel->updateHotelStatus($rtqId, $hotelId, 'sent to hotel');
        
        if ($statusUpdateSuccess) {
            log_message('info', "Hotel status updated successfully for RTQ ID: {$rtqId}, Hotel ID: {$hotelId}");
            $this->logActivity($rtqId, session()->get('user_id'), "Sent voucher to hotel: {$hotel['hotel_name']}");
            $emailSent = true;
        } else {
            log_message('error', "Failed to update hotel status after sending email for RTQ ID: {$rtqId}, Hotel ID: {$hotelId}");
        }
    } else {
        log_message('error', 'Email send error: ' . $email->printDebugger(['headers']));
    }

    if ($emailSent) {
        return $this->response->setJSON(['success' => true, 'message' => 'Voucher sent to hotel and status updated']);
    } else {
        return $this->response->setJSON(['success' => false, 'message' => 'Failed to send voucher or update status']);
    }
}
  
  
  
  
  
    

	public function cancel($id)
	{
    if ($this->rtqModel->update($id, ['status' => 'cancelled'])) {
        return $this->response->setJSON(['success' => true]);
    }
    return $this->response->setJSON(['success' => false]);
	}
}