<?php namespace App\Libraries;

require_once APPPATH . 'ThirdParty/tcpdf/tcpdf.php';

use TCPDF;
use Config\Tcpdf as TcpdfConfig;

class VoucherGenerator
{
    protected $tcpdf;

    public function __construct()
    {
        $config = new TcpdfConfig();
        $this->tcpdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);

        // Set the configuration
        $this->pdf->SetCreator(PDF_CREATOR);
        $this->pdf->SetAuthor('Your Company');
        $this->pdf->SetTitle('Booking Voucher');
        $this->pdf->SetSubject('Booking Voucher');
        $this->pdf->SetKeywords('Voucher, Booking, Hotel');

        // Remove default header/footer
        $this->pdf->setPrintHeader(false);
        $this->pdf->setPrintFooter(false);

        // Set default monospaced font
        $this->pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);

        // Set margins
        $this->pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);

        // Set auto page breaks
        $this->pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);

        // Set image scale factor
        $this->pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);

        // Set font
        $this->pdf->SetFont('helvetica', '', 10);
    }

    public function generateFullVoucher($rtq, $request, $hotels)
    {
        $this->pdf->AddPage();

        // Add a background color
        $this->pdf->Rect(0, 0, $this->pdf->getPageWidth(), $this->pdf->getPageHeight(), 'F', array(), array(240, 240, 240));

        // Title
        $this->pdf->SetFont('helvetica', 'B', 24);
        $this->pdf->SetTextColor(44, 62, 80);
        $this->pdf->Cell(0, 20, 'Booking Voucher', 0, 1, 'C');

        // Voucher Details
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Voucher Details', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->Cell(40, 7, 'RTQ ID:', 0, 0);
        $this->pdf->Cell(0, 7, $rtq['id'], 0, 1);
        $this->pdf->Cell(40, 7, 'Request ID:', 0, 0);
        $this->pdf->Cell(0, 7, $request['unique_id'], 0, 1);
        $this->pdf->Cell(40, 7, 'Booking Date:', 0, 0);
        $this->pdf->Cell(0, 7, date('Y-m-d', strtotime($request['created_at'])), 0, 1);

        // Flight Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Flight Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->Cell(40, 7, 'Arrival Flight:', 0, 0);
        $this->pdf->Cell(0, 7, $request['arrival_flight_number'], 0, 1);
        $this->pdf->Cell(40, 7, 'Departure Flight:', 0, 0);
        $this->pdf->Cell(0, 7, $request['departure_flight_number'], 0, 1);

        // Passenger Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Passenger Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        foreach ($request['passengers'] as $passenger) {
            $this->pdf->Cell(0, 7, $passenger['name'] . ' ' . $passenger['surname'] . ' (' . ucfirst($passenger['gender']) . ')', 0, 1);
        }

        // Hotel Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Hotel Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        foreach ($hotels as $hotel) {
            $this->pdf->SetFont('helvetica', 'B', 11);
            $this->pdf->Cell(0, 7, $hotel['hotel_name'], 0, 1);
            $this->pdf->SetFont('helvetica', '', 10);
            $this->pdf->Cell(40, 7, 'Room Type:', 0, 0);
            $this->pdf->Cell(0, 7, $hotel['room_type'], 0, 1);
            $this->pdf->Cell(40, 7, 'Check-in:', 0, 0);
            $this->pdf->Cell(60, 7, $hotel['check_in'], 0, 0);
            $this->pdf->Cell(40, 7, 'Check-out:', 0, 0);
            $this->pdf->Cell(0, 7, $hotel['check_out'], 0, 1);
            $this->pdf->Cell(40, 7, 'Nights:', 0, 0);
            $this->pdf->Cell(60, 7, $hotel['nights'], 0, 0);
            $this->pdf->Cell(40, 7, 'Room Quantity:', 0, 0);
            $this->pdf->Cell(0, 7, $hotel['room_quantity'], 0, 1);
            $this->pdf->Ln(3);
        }

        // Footer
        $this->pdf->SetY(-15);
        $this->pdf->SetFont('helvetica', 'I', 8);
        $this->pdf->Cell(0, 10, 'This is a computer-generated document and does not require a signature.', 0, 0, 'C');

        // Output the PDF as a string
        return $this->pdf->Output('voucher.pdf', 'S');
    }


	

    public function generateHotelVoucher($rtq, $request, $hotel)
    {
        $this->pdf->AddPage();

        // Add a background color
        $this->pdf->Rect(0, 0, $this->pdf->getPageWidth(), $this->pdf->getPageHeight(), 'F', array(), array(240, 240, 240));

        // Title
        $this->pdf->SetFont('helvetica', 'B', 24);
        $this->pdf->SetTextColor(44, 62, 80);
        $this->pdf->Cell(0, 20, 'Hotel Booking Voucher', 0, 1, 'C');

        // Voucher Details
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Voucher Details', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->Cell(40, 7, 'RTQ ID:', 0, 0);
        $this->pdf->Cell(0, 7, $rtq['id'], 0, 1);
        $this->pdf->Cell(40, 7, 'Request ID:', 0, 0);
        $this->pdf->Cell(0, 7, $request['unique_id'], 0, 1);
        $this->pdf->Cell(40, 7, 'Booking Date:', 0, 0);
        $this->pdf->Cell(0, 7, date('Y-m-d', strtotime($rtq['created_at'])), 0, 1);

        // Flight Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Flight Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->Cell(40, 7, 'Arrival Flight:', 0, 0);
        $this->pdf->Cell(0, 7, $request['arrival_flight_number'] ?? 'N/A', 0, 1);
        $this->pdf->Cell(40, 7, 'Departure Flight:', 0, 0);
        $this->pdf->Cell(0, 7, $request['departure_flight_number'] ?? 'N/A', 0, 1);

        // Passenger Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Passenger Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->SetTextColor(0, 0, 0);
        if (isset($request['passengers']) && is_array($request['passengers'])) {
            foreach ($request['passengers'] as $passenger) {
                $this->pdf->Cell(0, 7, ($passenger['name'] ?? 'N/A') . ' ' . ($passenger['surname'] ?? 'N/A') . ' (' . ucfirst($passenger['gender'] ?? 'N/A') . ')', 0, 1);
            }
        } else {
            $this->pdf->Cell(0, 7, 'No passenger information available', 0, 1);
        }

        // Hotel Information
        $this->pdf->Ln(5);
        $this->pdf->SetFont('helvetica', 'B', 12);
        $this->pdf->SetTextColor(52, 73, 94);
        $this->pdf->Cell(0, 10, 'Hotel Information', 0, 1, 'L');
        $this->pdf->SetFont('helvetica', 'B', 11);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->Cell(0, 7, $hotel['hotel_name'] ?? 'N/A', 0, 1);
        $this->pdf->SetFont('helvetica', '', 10);
        $this->pdf->Cell(40, 7, 'Room Type:', 0, 0);
        $this->pdf->Cell(0, 7, $hotel['room_type'] ?? 'N/A', 0, 1);
        $this->pdf->Cell(40, 7, 'Check-in:', 0, 0);
        $this->pdf->Cell(60, 7, $hotel['check_in'] ?? 'N/A', 0, 0);
        $this->pdf->Cell(40, 7, 'Check-out:', 0, 0);
        $this->pdf->Cell(0, 7, $hotel['check_out'] ?? 'N/A', 0, 1);
        $this->pdf->Cell(40, 7, 'Nights:', 0, 0);
        $this->pdf->Cell(60, 7, $hotel['nights'] ?? 'N/A', 0, 0);
        $this->pdf->Cell(40, 7, 'Room Quantity:', 0, 0);
        $this->pdf->Cell(0, 7, $hotel['room_quantity'] ?? 'N/A', 0, 1);
        $this->pdf->Cell(40, 7, 'Extra Bed:', 0, 0);
        $this->pdf->Cell(0, 7, isset($hotel['extra_bed']) && $hotel['extra_bed'] ? 'Yes' : 'No', 0, 1);

        // Footer
        $this->pdf->SetY(-15);
        $this->pdf->SetFont('helvetica', 'I', 8);
        $this->pdf->Cell(0, 10, 'This is a computer-generated document and does not require a signature.', 0, 0, 'C');

        // Output the PDF as a string
        return $this->pdf->Output('hotel_voucher.pdf', 'S');
    }

}