<?php

namespace App\Models;

use CodeIgniter\Model;

class RequestModel extends Model
{
    protected $table = 'requests';
    protected $primaryKey = 'id';
    protected $allowedFields = ['unique_id', 'user_id', 'arrival_flight_id', 'departure_flight_id', 'status', 'created_at', 'updated_at'];

    public function getAllRequests()
    {
        return $this->select('requests.*, IFNULL(users.username, "Unknown") as username')
                    ->join('users', 'users.id = requests.user_id', 'left')
                    ->orderBy('requests.created_at', 'DESC')
                    ->findAll();
    }

    public function getUserRequests($userId)
    {
        return $this->where('user_id', $userId)
                    ->orderBy('created_at', 'DESC')
                    ->findAll();
    }

    public function getRequestDetails($id)
	{
    $request = $this->select('requests.*, users.username, f1.flight_number as arrival_flight_number, f2.flight_number as departure_flight_number')
                   ->join('users', 'users.id = requests.user_id')
                   ->join('flights as f1', 'f1.id = requests.arrival_flight_id', 'left')
                   ->join('flights as f2', 'f2.id = requests.departure_flight_id', 'left')
                   ->where('requests.id', $id)
                   ->first();

    if ($request) {
        $request['hotels'] = $this->db->table('request_hotels')
            ->select('request_hotels.*, hotels.name as hotel_name, room_types.name as room_type')
            ->join('hotels', 'hotels.id = request_hotels.hotel_id')
            ->join('rooms', 'rooms.id = request_hotels.room_id')
            ->join('room_types', 'room_types.id = rooms.room_type_id')
            ->where('request_hotels.request_id', $id)
            ->get()->getResultArray();

        $request['passengers'] = $this->getRequestPassengers($id);
    }

    return $request;
	}
  
  
  
  	public function getRequestHotels($requestId)
	{
    $db = \Config\Database::connect();
    $builder = $db->table('request_hotels');
    $builder->select('request_hotels.*, hotels.name as hotel_name, room_types.name as room_type')
            ->join('hotels', 'hotels.id = request_hotels.hotel_id', 'left')
            ->join('rooms', 'rooms.id = request_hotels.room_id', 'left')
            ->join('room_types', 'room_types.id = rooms.room_type_id', 'left')
            ->where('request_hotels.request_id', $requestId);

    $query = $builder->get();
    $result = $query->getResultArray();
    
    // Add this line for debugging
    log_message('debug', 'Hotel data for request ' . $requestId . ': ' . print_r($result, true));

    return $result;
	}

    protected function getRequestPassengers($requestId)
    {
        $db = \Config\Database::connect();
        return $db->table('passengers')
                  ->where('request_id', $requestId)
                  ->get()
                  ->getResultArray();
    }

    public function searchRequests($searchTerm)
    {
        return $this->select('requests.*, IFNULL(users.username, "Unknown") as username')
                    ->join('users', 'users.id = requests.user_id', 'left')
                    ->like('requests.unique_id', $searchTerm)
                    ->orLike('users.username', $searchTerm)
                    ->orderBy('requests.created_at', 'DESC')
                    ->findAll();
    }
  
  	
}