<?php

namespace App\Models;

use CodeIgniter\Model;

class RequestToHotel extends Model
{
    protected $table = 'request_to_hotel';
    protected $primaryKey = 'id';
    protected $useAutoIncrement = true;
    protected $returnType = 'array';
    protected $allowedFields = [
        'request_id', 'hotel_id', 'status', 'voucher_path', 'created_at', 'updated_at'
    ];

    protected $useTimestamps = true;
    protected $createdField  = 'created_at';
    protected $updatedField  = 'updated_at';

    protected $validationRules = [
        'request_id' => 'required|integer',
        'hotel_id' => 'required|integer',
        'status' => 'required|in_list[need action,sent to hotel,hotel confirmed,hotel declined,needs update]',
    ];

    public function getRequestToHotelDetails($requestId)
    {
        return $this->where('request_id', $requestId)
                    ->join('hotels', 'hotels.id = request_to_hotel.hotel_id')
                    ->findAll();
    }

    public function updateStatus($id, $status)
    {
        return $this->update($id, ['status' => $status]);
    }

    public function setVoucherPath($id, $path)
    {
        return $this->update($id, ['voucher_path' => $path]);
    }
}