<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>
<div class="card">
    <div class="card-header">
        <h3 class="card-title">Room Management</h3>
    </div>
    <div class="card-body">
        <button type="button" class="btn btn-primary mb-3" data-toggle="modal" data-target="#addRoomTypeModal">
            Add New Room Type
        </button>
        <button type="button" class="btn btn-success mb-3" data-toggle="modal" data-target="#addRoomModal">
            Add Room to Hotel
        </button>
        
        <h4>Room Types</h4>
        <table class="table table-bordered table-striped mb-4">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Room Type Name</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($roomTypes as $roomType): ?>
                <tr>
                    <td><?= $roomType['id'] ?></td>
                    <td><?= esc($roomType['name']) ?></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <h4>Hotel Room Associations</h4>
        <table class="table table-bordered table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Hotel</th>
                    <th>Room Type</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($hotelRooms as $room): ?>
                <tr>
                    <td><?= $room['id'] ?></td>
                    <td><?= esc($hotels[$room['hotel_id']]['name']) ?></td>
                    <td><?= esc($roomTypes[$room['room_type_id']]['name']) ?></td>
                    <td>
                        <button class="btn btn-danger btn-sm delete-room" data-id="<?= $room['id'] ?>">Delete</button>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- Add Room Type Modal -->
<div class="modal fade" id="addRoomTypeModal" tabindex="-1" role="dialog" aria-labelledby="addRoomTypeModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addRoomTypeModalLabel">Add New Room Type</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="addRoomTypeForm">
                    <div class="form-group">
                        <label for="roomTypeName">Room Type Name</label>
                        <input type="text" class="form-control" id="roomTypeName" name="name" required>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary" id="submitRoomType">Add Room Type</button>
            </div>
        </div>
    </div>
</div>

<!-- Add Room Modal -->
<div class="modal fade" id="addRoomModal" tabindex="-1" role="dialog" aria-labelledby="addRoomModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addRoomModalLabel">Add Room to Hotel</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="addRoomForm">
                    <div class="form-group">
                        <label for="roomTypeId">Room Type</label>
                        <select class="form-control" id="roomTypeId" name="room_type_id" required>
                            <?php foreach ($roomTypes as $roomType): ?>
                                <option value="<?= $roomType['id'] ?>"><?= esc($roomType['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="hotelId">Hotel</label>
                        <select class="form-control" id="hotelId" name="hotel_id" required>
                            <?php foreach ($hotels as $hotel): ?>
                                <option value="<?= $hotel['id'] ?>"><?= esc($hotel['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary" id="submitRoom">Add Room</button>
            </div>
        </div>
    </div>
</div>

<script>
$(document).ready(function() {
    $('#submitRoomType').click(function() {
        $.ajax({
            url: '<?= base_url('room-management/addRoomType') ?>',
            type: 'POST',
            data: $('#addRoomTypeForm').serialize(),
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    alert(response.message);
                    location.reload();
                } else {
                    alert('Error: ' + (response.message ? response.message : 'Unknown error occurred'));
                }
            },
            error: function(xhr, status, error) {
                console.error(xhr.responseText);
                alert('An error occurred. Please try again.');
            }
        });
    });

    $('#submitRoom').click(function() {
        $.ajax({
            url: '<?= base_url('room-management/add') ?>',
            type: 'POST',
            data: $('#addRoomForm').serialize(),
            dataType: 'json',
            success: function(response) {
                if (response.success) {
                    alert(response.message);
                    location.reload();
                } else {
                    alert('Error: ' + response.message);
                }
            },
            error: function(xhr, status, error) {
                console.error(xhr.responseText);
                alert('An error occurred. Please try again.');
            }
        });
    });

    $('.delete-room').click(function() {
        if (confirm('Are you sure you want to delete this room?')) {
            var roomId = $(this).data('id');
            $.ajax({
                url: '<?= base_url('room-management/delete') ?>/' + roomId,
                type: 'POST',
                dataType: 'json',
                success: function(response) {
                    if (response.success) {
                        alert(response.message);
                        location.reload();
                    } else {
                        alert('Error: ' + response.message);
                    }
                },
                error: function(xhr, status, error) {
                    console.error(xhr.responseText);
                    alert('An error occurred. Please try again.');
                }
            });
        }
    });
});
</script>
<?= $this->endSection() ?>